==> crm-commom-vo-1.2.4.11.release.jar: com/biz/crm/nebular/mdm/CrmExtVo.java <==
package com.biz.crm.nebular.mdm;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description: 拓展字段entity,用于需要拓展字段的实体
 * @Author: zhangyuzhu
 * @Date: 2020/8/19 10:08
 **/
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@Data
public class CrmExtVo extends CrmBaseVo {

    @ApiModelProperty("扩展信息1")
    private String ext1 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息1")
    private String ext2 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息3")
    private String ext3 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息4")
    private String ext4 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息5")
    private String ext5 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息6")
    private String ext6 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息7")
    private String ext7 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息8")
    private String ext8 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息9")
    private String ext9 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息10")
    private String ext10 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息11")
    private String ext11 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息12")
    private String ext12 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息13")
    private String ext13 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息14")
    private String ext14 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息15")
    private String ext15 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息16")
    private String ext16 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息17")
    private String ext17 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息18")
    private String ext18 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息19")
    private String ext19 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息20")
    private String ext20 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息21")
    private String ext21 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息22")
    private String ext22 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息23")
    private String ext23 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息24")
    private String ext24 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息25")
    private String ext25 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息26")
    private String ext26 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息27")
    private String ext27 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息28")
    private String ext28 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息29")
    private String ext29 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息30")
    private String ext30 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息31")
    private String ext31 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息32")
    private String ext32 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息33")
    private String ext33 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息34")
    private String ext34 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息35")
    private String ext35 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息36")
    private String ext36 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息37")
    private String ext37 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息38")
    private String ext38 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息39")
    private String ext39 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息40")
    private String ext40 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息41")
    private String ext41 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息42")
    private String ext42 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息43")
    private String ext43 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息44")
    private String ext44 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息45")
    private String ext45 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息46")
    private String ext46 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息47")
    private String ext47 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息48")
    private String ext48 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息49")
    private String ext49 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息50")
    private String ext50 = StringUtils.EMPTY;
}

==> crm-commom-vo-1.2.9.release.jar: com/biz/crm/nebular/mdm/CrmExtVo.java <==
package com.biz.crm.nebular.mdm;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description: 拓展字段entity,用于需要拓展字段的实体
 * @Author: zhangyuzhu
 * @Date: 2020/8/19 10:08
 **/
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@Data
public class CrmExtVo extends CrmExtTenVo {

    @ApiModelProperty("扩展信息1")
    private String ext1 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息1")
    private String ext2 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息3")
    private String ext3 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息4")
    private String ext4 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息5")
    private String ext5 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息6")
    private String ext6 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息7")
    private String ext7 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息8")
    private String ext8 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息9")
    private String ext9 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息10")
    private String ext10 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息11")
    private String ext11 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息12")
    private String ext12 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息13")
    private String ext13 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息14")
    private String ext14 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息15")
    private String ext15 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息16")
    private String ext16 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息17")
    private String ext17 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息18")
    private String ext18 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息19")
    private String ext19 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息20")
    private String ext20 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息21")
    private String ext21 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息22")
    private String ext22 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息23")
    private String ext23 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息24")
    private String ext24 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息25")
    private String ext25 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息26")
    private String ext26 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息27")
    private String ext27 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息28")
    private String ext28 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息29")
    private String ext29 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息30")
    private String ext30 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息31")
    private String ext31 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息32")
    private String ext32 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息33")
    private String ext33 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息34")
    private String ext34 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息35")
    private String ext35 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息36")
    private String ext36 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息37")
    private String ext37 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息38")
    private String ext38 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息39")
    private String ext39 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息40")
    private String ext40 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息41")
    private String ext41 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息42")
    private String ext42 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息43")
    private String ext43 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息44")
    private String ext44 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息45")
    private String ext45 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息46")
    private String ext46 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息47")
    private String ext47 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息48")
    private String ext48 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息49")
    private String ext49 = StringUtils.EMPTY;

    @ApiModelProperty("扩展信息50")
    private String ext50 = StringUtils.EMPTY;
}
